/*
 * This is part of XmlEditor, a graphical editor for XML files
 * Copyright (C) 2001 CERN - Sebastien Ponce
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Contacts :
 *   sebastien.ponce@polytechnique.org
 *   http://lhcb-comp.web.cern.ch/lhcb-comp/
 *   http://www.cern.ch
 */

package ch.cern.lhcb.xmleditor.gui;

import java.awt.Component;
import java.awt.Dimension;
import java.awt.Frame;
import java.awt.Label;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.BoxLayout;
import javax.swing.JComboBox;
import javax.swing.JDialog;
import javax.swing.JPanel;
import javax.swing.JScrollPane;

import ch.cern.lhcb.xmleditor.specific.XmlDisplay;

public abstract class AbstractDialog extends JDialog implements ActionListener {

    /**
     * a ComboBox where the element names appear
     */
    protected JComboBox box;

    /**
     * a panel for displaying details about elements
     */
    protected JPanel panel;

    /**
     * the XmlDisplay currently used
     */
    protected XmlDisplay xmlDisplay;

    /**
     * constructor : builds the dialog
     * 
     * @param owner the frame where this dialog should appear
     * @param title the title of the dialog
     * @param xmlDisplay the XmlDisplay that must be used
     */
    public AbstractDialog(Frame owner, String title, XmlDisplay xmlDisplay) {
        // calls the constructor of the super class
        super(owner, title, true);
        // saves a pointer on the current XmlDisplay
        this.xmlDisplay = xmlDisplay;
        // adds a box layout
        this.getContentPane().setLayout(
                new BoxLayout(this.getContentPane(), BoxLayout.Y_AXIS));
        // builds a comboBox with all possible elements
        box = new JComboBox(xmlDisplay.getElementNames());
        box.addActionListener(this);
        box.setMaximumSize(new Dimension(200, 22));
        box.setAlignmentX(Component.CENTER_ALIGNMENT);
        // builds the panel for element choice
        JPanel elementPanel = new JPanel();
        elementPanel.add(new Label("Element"));
        elementPanel.add(box);
        this.getContentPane().add(elementPanel);
        // builds the panel for details
        panel = new JPanel();
        // build a scroll Panel to contain the panel
        JScrollPane scrollPane = new JScrollPane(panel);
        scrollPane.setPreferredSize(new Dimension(400, 200));
        this.getContentPane().add(scrollPane);
    }

    /**
     * builds the panel for a given element name of a given XmlDisplay by
     * displaying some subelements
     * 
     * @param name the name of the element for which the panel should be built
     * @param xmlDisplay the XmlDisplay dealing with the dtd in which the
     *        element name was declared
     */
    protected abstract void buildPanel(String name, XmlDisplay xmlDisplay);

    /**
     * called each time an action event occurs
     * 
     * @param e the ActionEvent
     */
    public void actionPerformed(ActionEvent e) {
        if (e.getSource() == box) {
            // cleans the panel
            panel.removeAll();
            this.repaint();
            // rebuilds the panel
            buildPanel((String) box.getSelectedItem(), xmlDisplay);
            this.validate();
        }
    }

}