/*
 * This is part of XmlEditor, a graphical editor for XML files
 * Copyright (C) 2001 CERN - Sebastien Ponce
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Contacts :
 *   sebastien.ponce@polytechnique.org
 *   http://lhcb-comp.web.cern.ch/lhcb-comp/
 *   http://www.cern.ch
 */

package ch.cern.lhcb.xmleditor.undo;

import javax.swing.undo.CannotRedoException;
import javax.swing.undo.CannotUndoException;

import org.w3c.dom.Document;

import ch.cern.lhcb.xmleditor.gui.XmlTreeNode;

/**
 * this is an implementation of the abstract class AbstractUndoableEdit that
 * defines the undoable close reference in an XmlTree.
 */

public class UndoableCloseReference extends AbstractUndoableEdit {

    /**
     * the XmlTreeNode concerned
     */
    private XmlTreeNode treeNode;

    /**
     * Constructor. Specifies the XmlTreeNode concerned.
     * 
     * @param document the document this Edit is associated with
     * @param treeNode the XmlTreeNode concerned
     */
    public UndoableCloseReference(Document document, XmlTreeNode treeNode) {
        super(document);
        this.treeNode = treeNode;
    }

    /**
     * Redoes the operation represented by this edit
     * 
     * @throws CannotRedoException if canRedo() returns false
     */
    public void redo() throws CannotRedoException {
        super.redo();
        // closes the reference
        XmlTreeNode newNode = treeNode.getNewNode();
        newNode.getXmlTree().collapseReference(newNode);
    }

    /**
     * Undoes the operation represented by this edit
     * 
     * @throws CannotUndoException if canUndo() returns false
     */
    public void undo() throws CannotUndoException {
        super.undo();
        // expands the reference
        treeNode.getXmlTree().expandReference(treeNode);
    }

    /**
     * returns an appropriate description of the operation this edit represents.
     * 
     * @return a description of the operation
     */
    public String getPresentationName() {
        return "close " + treeNode.getNode().getNodeName();
    }

}