/*
 * com.simulogic.cese -- Cell Electrophysiology Simulation Environment (CESE)
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 *
 * Dalhousie Univ., Halifax, NS, Canada
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.cese.cellml;

import java.io.File;
import java.net.URL;

import javax.xml.transform.Templates;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;

import com.simulogic.cese.ResourceManager;
import com.simulogic.cese.UserHome;
import com.sun.org.apache.xalan.internal.xsltc.trax.TransformerFactoryImpl;

/**
 * Class that transforms models in CellML format ( <a
 * href="http://www.cellml.org">www.cellml.org </a>) to the JavaBeans source
 * code using XSL stylesheet(s).
 */
public class CellMLTransformer {

	
    /**
     * Location of stylesheets
     */
    public static final String styles = "com/simulogic/cese/stylesheets/";
    
    /**
     * Stylesheet name
     */
    public static final String stylesheet = "cellml2Java.xsl";

    private static CellMLTransformer transformer = null;

    /**
     * Returns the main program
     * 
     * @return transformer instance
     */
    public static CellMLTransformer getTransformer() {
        return transformer;
    }

    /**
     * Perform transformation
     * 
     * @param fn name of CellML source document
     */
    public void transform(String fn) {
        try {
            System.out.println("Converting: " + fn);

            URL styleUrl = ClassLoader.getSystemResource(styles + stylesheet);

            File workDir = new File(UserHome.CESE_HOME + UserHome.FS
                    + ResourceManager.getResource("cellml_dir"));

            TransformerFactory factory = new TransformerFactoryImpl();
            Templates templates = factory.newTemplates(new StreamSource(
                    styleUrl.toExternalForm()));

            Transformer transform = templates.newTransformer();
            transform.setParameter("packageName", "com.simulogic.cese.models");

            String fileName = workDir.getAbsolutePath() + UserHome.FS + fn;
            System.out.println("Source: " + fileName);

            String className = fn.substring(0, fn.lastIndexOf('.'));
            transform.setParameter("className", className);
            transform.setParameter("baseClassName", "AbstractAPModel");

            String outName = new String(workDir.getAbsolutePath() + UserHome.FS
                    + className + ".java");

            transform.transform(new StreamSource(new File(fileName)),
                    new StreamResult(new File(outName)));

            System.out.println("Destination: " + outName);

        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * Main method
     * 
     * @param args
     */
    public static void main(java.lang.String[] args) {
        transformer = new CellMLTransformer();
        transformer.transform(args[0]);
    }
}
