/*
 * com.simulogic.dataview -- The Java2D Plotting Framework
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.dataview;

import java.awt.Color;
import java.awt.Font;

import javax.swing.Box;

/**
 * Generates dialog box for changing axis properties
 */
public class AxisProperties extends javax.swing.JDialog {

    /** A return status code - returned if Cancel button has been pressed */
    public static final int RET_CANCEL = 0;
    /** A return status code - returned if OK button has been pressed */
    public static final int RET_OK = 1;

    private DataAxis axis;

    /**
     * Default constructor
     * 
     * @param parent parent frame
     * @param ax axis
     */
    public AxisProperties(java.awt.Frame parent, DataAxis ax) {
        super(parent, true);
        initComponents();
        setAxis(ax);
        
        if (axis.getOrientation() == DataAxis.AXIS_HORIZONTAL) {
            yminField.setEditable(false);
            ymaxField.setEditable(false);
        } else {
            xminField.setEditable(false);
            xmaxField.setEditable(false);
        }
    
        pack();
        setResizable(false);
        setLocationRelativeTo(getOwner());
    }

    /**
     * Returns status of this dialog
     * 
     * @return the return status of this dialog - one of RET_OK or RET_CANCEL
     */
    public int getReturnStatus() {
        return returnStatus;
    }

    private void initComponents() {
        axisFontEditor = new javax.swing.beaninfo.SwingFontEditor();
        axisBackgroundColorEditor = new javax.swing.beaninfo.SwingColorEditor();
        axisMarksColorEditor = new javax.swing.beaninfo.SwingColorEditor();
        axisTicksColorEditor = new javax.swing.beaninfo.SwingColorEditor();
        axisScaleColorEditor = new javax.swing.beaninfo.SwingColorEditor();
        axisBaseColorEditor = new javax.swing.beaninfo.SwingColorEditor();
        buttonPanel = new javax.swing.JPanel();
        okButton = new javax.swing.JButton();
        cancelButton = new javax.swing.JButton();
        viewPanel = new javax.swing.JTabbedPane();
        propertyPanel = new javax.swing.JPanel();
        backgroundPanel = new javax.swing.JPanel();
        backgroundLabel = new javax.swing.JLabel();
        baseColorPanel = new javax.swing.JPanel();
        baseColorLabel = new javax.swing.JLabel();
        scaleColorPanel = new javax.swing.JPanel();
        scaleColorLabel = new javax.swing.JLabel();
        ticksPanel = new javax.swing.JPanel();
        fontPanel = new javax.swing.JPanel();
        fontLabel = new javax.swing.JLabel();
        marksColorPanel = new javax.swing.JPanel();
        marksColorLabel = new javax.swing.JLabel();
        ticksColorPanel = new javax.swing.JPanel();
        ticksColorLabel = new javax.swing.JLabel();
        scalePanel = new javax.swing.JPanel();
        xPanel = new javax.swing.JPanel();
        xminPanel = new javax.swing.JPanel();
        xminLabel = new javax.swing.JLabel();
        xminField = new com.simulogic.utils.DoubleField();
        xmaxPanel = new javax.swing.JPanel();
        xmaxLabel = new javax.swing.JLabel();
        xmaxField = new com.simulogic.utils.DoubleField();
        yPanel = new javax.swing.JPanel();
        yminPanel = new javax.swing.JPanel();
        yminLabel = new javax.swing.JLabel();
        yminField = new com.simulogic.utils.DoubleField();
        ymaxPanel = new javax.swing.JPanel();
        ymaxLabel = new javax.swing.JLabel();
        ymaxField = new com.simulogic.utils.DoubleField();

        java.awt.GridBagConstraints gridBagConstraints;

        setTitle(ResourceManager.getResource("Axis_Properties"));
        setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        addWindowListener(new java.awt.event.WindowAdapter() {

            public void windowClosing(java.awt.event.WindowEvent evt) {
                closeDialog();
            }
        });

        buttonPanel
                .setLayout(new java.awt.FlowLayout(java.awt.FlowLayout.RIGHT));

        okButton.setText(ResourceManager.getResource("OK"));
        okButton.addActionListener(new java.awt.event.ActionListener() {

            public void actionPerformed(java.awt.event.ActionEvent evt) {
                okButtonActionPerformed();
            }
        });

        buttonPanel.add(okButton);

        cancelButton.setText(ResourceManager.getResource("Cancel"));
        cancelButton.addActionListener(new java.awt.event.ActionListener() {

            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cancelButtonActionPerformed();
            }
        });

        buttonPanel.add(cancelButton);

        getContentPane().add(buttonPanel, java.awt.BorderLayout.SOUTH);

        propertyPanel.setLayout(new javax.swing.BoxLayout(propertyPanel,
                javax.swing.BoxLayout.Y_AXIS));

        propertyPanel.setBorder(new javax.swing.border.EmptyBorder(
                new java.awt.Insets(4, 4, 4, 4)));
        backgroundPanel.setLayout(new javax.swing.BoxLayout(backgroundPanel,
                javax.swing.BoxLayout.X_AXIS));

        backgroundLabel.setText(ResourceManager
                .getResource("Background_Color_"));
        baseColorLabel.setDisplayedMnemonic('a');
        backgroundLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        backgroundLabel
                .setLabelFor(axisBackgroundColorEditor.getCustomEditor());
        backgroundPanel.add(backgroundLabel);

        propertyPanel.add(backgroundPanel);

        baseColorPanel.setLayout(new javax.swing.BoxLayout(baseColorPanel,
                javax.swing.BoxLayout.X_AXIS));

        baseColorLabel.setText(ResourceManager.getResource("Baseline_Color_"));
        baseColorLabel.setDisplayedMnemonic('b');
        baseColorLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        baseColorLabel.setLabelFor(axisBaseColorEditor.getCustomEditor());
        baseColorPanel.add(baseColorLabel);

        propertyPanel.add(baseColorPanel);

        scaleColorPanel.setLayout(new javax.swing.BoxLayout(scaleColorPanel,
                javax.swing.BoxLayout.X_AXIS));

        scaleColorLabel.setText(ResourceManager.getResource("Scale_Color_"));
        scaleColorLabel.setDisplayedMnemonic('s');
        scaleColorLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        scaleColorLabel.setLabelFor(axisScaleColorEditor.getCustomEditor());
        scaleColorPanel.add(scaleColorLabel);

        propertyPanel.add(scaleColorPanel);

        ticksPanel.setLayout(new javax.swing.BoxLayout(ticksPanel,
                javax.swing.BoxLayout.Y_AXIS));

        ticksPanel.setBorder(new javax.swing.border.TitledBorder(
                new javax.swing.border.EtchedBorder(), ResourceManager
                        .getResource("Ticks_properties")));
        fontPanel.setLayout(new javax.swing.BoxLayout(fontPanel,
                javax.swing.BoxLayout.X_AXIS));

        fontLabel.setText(ResourceManager.getResource("Ticks_Labels_Font_"));
        fontLabel.setDisplayedMnemonic('f');
        fontLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        fontLabel.setLabelFor(axisFontEditor.getCustomEditor());
        fontPanel.add(fontLabel);

        ticksPanel.add(fontPanel);

        marksColorPanel.setLayout(new javax.swing.BoxLayout(marksColorPanel,
                javax.swing.BoxLayout.X_AXIS));

        marksColorLabel.setText(ResourceManager
                .getResource("Ticks_Labels_Color_"));
        marksColorLabel.setDisplayedMnemonic('l');
        marksColorLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        marksColorLabel.setLabelFor(axisMarksColorEditor.getCustomEditor());
        marksColorPanel.add(marksColorLabel);

        ticksPanel.add(marksColorPanel);

        ticksColorPanel.setLayout(new javax.swing.BoxLayout(ticksColorPanel,
                javax.swing.BoxLayout.X_AXIS));

        ticksColorLabel.setText(ResourceManager.getResource("Ticks_Color_"));
        ticksColorLabel.setDisplayedMnemonic('c');
        ticksColorLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        ticksColorLabel.setLabelFor(axisTicksColorEditor.getCustomEditor());
        ticksColorPanel.add(ticksColorLabel);

        ticksPanel.add(ticksColorPanel);

        propertyPanel.add(ticksPanel);

        viewPanel.addTab("Visual", null, propertyPanel, "");

        scalePanel.setLayout(new java.awt.GridBagLayout());

        scalePanel.setBorder(new javax.swing.border.EmptyBorder(
                new java.awt.Insets(4, 4, 4, 4)));
        xPanel.setLayout(new java.awt.GridLayout(1, 2, 5, 0));

        xminLabel.setText(ResourceManager.getResource("Min_x_"));
        xminLabel.setDisplayedMnemonic('x');
        xminLabel.setLabelFor(xminField);
        xminLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        xminPanel.add(xminLabel);

        xminPanel.add(xminField);

        xPanel.add(xminPanel);

        xmaxLabel.setText(ResourceManager.getResource("Max_x_"));
        xmaxLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        xmaxPanel.add(xmaxLabel);

        xmaxPanel.add(xmaxField);

        xPanel.add(xmaxPanel);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        scalePanel.add(xPanel, gridBagConstraints);

        yPanel.setLayout(new java.awt.GridLayout(1, 2, 5, 0));

        yminLabel.setText(ResourceManager.getResource("Min_y_"));
        yminLabel.setDisplayedMnemonic('y');
        yminLabel.setLabelFor(yminField);
        yminLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        yminPanel.add(yminLabel);

        yminPanel.add(yminField);

        yPanel.add(yminPanel);

        ymaxLabel.setText(ResourceManager.getResource("Max_y_"));
        ymaxLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        ymaxPanel.add(ymaxLabel);

        ymaxPanel.add(ymaxField);

        yPanel.add(ymaxPanel);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        scalePanel.add(yPanel, gridBagConstraints);

        viewPanel.addTab("Scale", scalePanel);

        fontPanel.add(Box.createHorizontalGlue());
        fontPanel.add(axisFontEditor.getCustomEditor());
        backgroundPanel.add(Box.createHorizontalGlue());
        backgroundPanel.add(axisBackgroundColorEditor.getCustomEditor());
        marksColorPanel.add(Box.createHorizontalGlue());
        marksColorPanel.add(axisMarksColorEditor.getCustomEditor());
        ticksColorPanel.add(Box.createHorizontalGlue());
        ticksColorPanel.add(axisTicksColorEditor.getCustomEditor());
        scaleColorPanel.add(Box.createHorizontalGlue());
        scaleColorPanel.add(axisScaleColorEditor.getCustomEditor());
        baseColorPanel.add(Box.createHorizontalGlue());
        baseColorPanel.add(axisBaseColorEditor.getCustomEditor());

        getContentPane().add(viewPanel, java.awt.BorderLayout.CENTER);

    }

    private void okButtonActionPerformed() {
        axis.setFont(((Font) axisFontEditor.getValue()));
        axis.setBackground(((Color) axisBackgroundColorEditor.getValue()));
        axis.setForeground(((Color) axisMarksColorEditor.getValue()));
        axis.setBaseColor(((Color) axisBaseColorEditor.getValue()));
        axis.setTicksColor(((Color) axisTicksColorEditor.getValue()));
        axis.setScaleColor(((Color) axisScaleColorEditor.getValue()));

        axis.getView().setScale(xminField.getValue(), ymaxField.getValue(),
                xmaxField.getValue() - xminField.getValue(),
                ymaxField.getValue() - yminField.getValue());

        doClose(RET_OK);
    }

    private void cancelButtonActionPerformed() {
        doClose(RET_CANCEL);
    }

    /** 
     * Closes the dialog 
     */
    private void closeDialog() {
        doClose(RET_CANCEL);
    }

    private void doClose(int retStatus) {
        returnStatus = retStatus;
        setVisible(false);
        dispose();
    }

    private javax.swing.JLabel marksColorLabel;
    private javax.swing.JPanel fontPanel;
    private javax.swing.JPanel xmaxPanel;
    private com.simulogic.utils.DoubleField ymaxField;
    private javax.swing.JPanel ticksPanel;
    private javax.swing.JButton okButton;
    private javax.swing.JPanel scalePanel;
    private javax.swing.JPanel xminPanel;
    private javax.swing.JPanel baseColorPanel;
    private com.simulogic.utils.DoubleField yminField;
    private javax.swing.JPanel ticksColorPanel;
    private javax.swing.JLabel fontLabel;
    private javax.swing.JLabel xmaxLabel;
    private javax.swing.JPanel buttonPanel;
    private javax.swing.JTabbedPane viewPanel;
    private javax.swing.beaninfo.SwingColorEditor axisBaseColorEditor;
    private javax.swing.beaninfo.SwingColorEditor axisTicksColorEditor;
    private javax.swing.beaninfo.SwingFontEditor axisFontEditor;
    private javax.swing.JPanel ymaxPanel;
    private javax.swing.JLabel xminLabel;
    private javax.swing.JLabel baseColorLabel;
    private javax.swing.JLabel ticksColorLabel;
    private javax.swing.JPanel yminPanel;
    private javax.swing.beaninfo.SwingColorEditor axisMarksColorEditor;
    private com.simulogic.utils.DoubleField xmaxField;
    private javax.swing.JPanel scaleColorPanel;
    private javax.swing.JPanel backgroundPanel;
    private javax.swing.JLabel ymaxLabel;
    private javax.swing.JPanel marksColorPanel;
    private com.simulogic.utils.DoubleField xminField;
    private javax.swing.JPanel xPanel;
    private javax.swing.beaninfo.SwingColorEditor axisBackgroundColorEditor;
    private javax.swing.JLabel yminLabel;
    private javax.swing.JPanel yPanel;
    private javax.swing.JLabel scaleColorLabel;
    private javax.swing.beaninfo.SwingColorEditor axisScaleColorEditor;
    private javax.swing.JLabel backgroundLabel;
    private javax.swing.JButton cancelButton;
    private javax.swing.JPanel propertyPanel;

    private int returnStatus = RET_CANCEL;

    /**
     * Sets new axis
     * 
     * @param ax data axis
     */
    public void setAxis(DataAxis ax) {
        this.axis = ax;
        axisFontEditor.setValue(axis.getFont());
        axisBackgroundColorEditor.setValue(axis.getBackground());
        axisBaseColorEditor.setValue(axis.getBaseColor());
        axisMarksColorEditor.setValue(axis.getForeground());
        axisTicksColorEditor.setValue(axis.getTicksColor());
        axisScaleColorEditor.setValue(axis.getScaleColor());

        xminField.setValue(axis.getView().getScale().getX());
        xmaxField.setValue(axis.getView().getScale().getX()
                + axis.getView().getScale().getWidth());
        yminField.setValue(axis.getView().getScale().getY()
                - axis.getView().getScale().getHeight());
        ymaxField.setValue(axis.getView().getScale().getY());

        getRootPane().setDefaultButton(okButton);
    }
}