/*
 * com.simulogic.dataview -- The Java2D Plotting Framework
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.dataview;

import java.util.Enumeration;
import java.util.Hashtable;

import javax.swing.BorderFactory;
import javax.swing.JProgressBar;
import javax.swing.ToolTipManager;

/**
 * This class displays the progress indicator for the background tasks
 */
public class TaskProgress extends JProgressBar {

    /**
     * List of all pending tasks
     */
    private Hashtable tasks = new Hashtable();

    /**
     * Creates new task progress bar
     */
    public TaskProgress() {
        super();

        this.setBorder(BorderFactory.createEmptyBorder());
        this.setStringPainted(true);
        this.setString("");
        this.setIndeterminate(false);
        this.setVisible(false);

        ToolTipManager.sharedInstance().registerComponent(this);
    }

    /**
     * Returns tooltip with information about running tasks
     * 
     * @return tooltip string
     */
    public String getToolTipText() {
        StringBuffer tip = new StringBuffer();
        tip.append("<html>");
        
        Enumeration keys = tasks.elements();
        int i = 0;
        while (keys.hasMoreElements()) {
            tip.append(i + 1);
            tip.append(": ");
            tip.append((String) keys.nextElement());
            if (i < tasks.size() - 1) tip.append("<br>");
        }
        tip.append("</html>");
        return tip.toString();
    }

    /**
     * Adds new task to list
     * 
     * @param t desription of the task
     */
    public void addTask(String t) {
        if (t != null) tasks.put(t, t);
        this.setString(tasks.size() + " "
                + ResourceManager.getResource("tasks_pending"));

        if (tasks.size() > 0) {
            this.setValue(tasks.size());
            this.setIndeterminate(true);
            this.setVisible(true);
        }
    }

    /**
     * Removes last task from the list
     */
    public void removeTask() {
        if (tasks.size() > 0) tasks.remove(0);
        this.setString(tasks.size() + " "
                + ResourceManager.getResource("tasks_pending"));

        if (tasks.size() == 0) {
            this.setValue(this.getMinimum());
            this.setIndeterminate(false);
            this.setString("");
            this.setVisible(false);
        }
    }
    

    /**
     * Removes last task from the list
     */
    public void removeTask(String t) {
        if (tasks.size() > 0) tasks.remove(t);
        this.setString(tasks.size() + " "
                + ResourceManager.getResource("tasks_pending"));

        if (tasks.size() == 0) {
            this.setValue(this.getMinimum());
            this.setIndeterminate(false);
            this.setString("");
            this.setVisible(false);
        }
    }

}