/*
 * com.simulogic.dataview -- The Java2D Plotting Framework
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.dataview.export;

import java.awt.Graphics2D;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;

import javax.imageio.ImageIO;

import com.simulogic.dataview.ViewContent;

/**
 * Class that exports data to PNG format
 */
public class PngExport {

	private com.simulogic.dataview.ViewContent view;

	/**
	 * Default constructor
	 * 
	 * @param v
	 *            view content
	 */
	public PngExport(ViewContent v) {
		view = v;
	}

	/**
	 * Exports the content of <code>DataView</code> to PNG graphics file
	 * 
	 * @param fileName
	 *            name of the file to export data
	 * @throws IOException
	 *             if i/o problem occurs
	 */
	public synchronized void export(String fileName) throws java.io.IOException {
		if (view.getView().isDisplayable()) {
			BufferedImage bi = new BufferedImage(view.getView().getScrollPane()
					.getWidth(), view.getView().getScrollPane().getHeight(),
					BufferedImage.TYPE_INT_RGB);
			Graphics2D g2 = bi.createGraphics();
			view.getView().getScrollPane().paint(g2);
			g2.dispose();

			ImageIO.write(bi, "png", new File(fileName));
		}
	}

}
