/*
 * Copyright (C) 2000 Sergey Missan. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modifica-
 * tion, are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 * 
 * 3. The end-user documentation included with the redistribution, if any, must
 * include the following acknowledgment: "This product includes software
 * developed by Sergey Missan (http://www.simulogic.com/)." Alternately, this
 * acknowledgment may appear in the software itself, if and wherever such
 * third-party acknowledgments normally appear.
 * 
 * 
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SERGEY
 * MISSAN OR simulogic OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NE-
 * GLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.simulogic.utils;

import java.awt.Toolkit;
import java.io.Serializable;
import java.text.NumberFormat;
import java.text.ParseException;
import java.util.Locale;

import javax.swing.JTextField;
import javax.swing.text.AttributeSet;
import javax.swing.text.BadLocationException;
import javax.swing.text.Document;
import javax.swing.text.PlainDocument;

public class IntegerField extends JTextField implements Serializable {

    private Toolkit toolkit;
    private NumberFormat integerFormatter;
    private int maxConstraint = Integer.MAX_VALUE;
    private int minConstraint = Integer.MIN_VALUE;

    public IntegerField() {
        this(0, 2);
    }

    public IntegerField(int value, int columns) {
        super(columns);
        toolkit = Toolkit.getDefaultToolkit();
        integerFormatter = NumberFormat.getNumberInstance(Locale.US);
        integerFormatter.setParseIntegerOnly(true);
        setValue(value);
    }

    public void setPositive(boolean p) {
        if (p == true) this.minConstraint = 0;
    }

    public int getValue() {
        int retVal = 0;
        try {
            retVal = integerFormatter.parse(getText()).intValue();
        } catch (ParseException e) {
            toolkit.beep();
        }
        return retVal;
    }

    public void setValue(int value) {
        try {
            if ((value >= minConstraint) && (value <= maxConstraint)) {
                setText(integerFormatter.format(value));
            } else {
                toolkit.beep();
            }
        } catch (NumberFormatException e) {
            toolkit.beep();
        }
    }

    protected Document createDefaultModel() {
        return new IntegerDocument();
    }

    private class IntegerDocument extends PlainDocument {

        public void insertString(int offs, String str, AttributeSet a)
                throws BadLocationException {
            char[] source = str.toCharArray();
            char[] result = new char[source.length];
            int j = 0;

            for (int i = 0; i < result.length; i++) {
                if (Character.isDigit(source[i])
                        || ((maxConstraint < 0) && (source[i] == '-'))) {
                    result[j++] = source[i];
                } else {
                    toolkit.beep();
                }
            }

            try {
                Integer i = new Integer(new StringBuffer(this.getText(0, this
                        .getLength())).insert(offs, new String(result, 0, j))
                        .toString());
                if ((i.intValue() >= minConstraint)
                        && (i.intValue() <= maxConstraint)) {
                    super.insertString(offs, new String(result, 0, j), a);
                } else {
                    toolkit.beep();
                }
            } catch (NumberFormatException e) {
            }
        }
    }

    public int getMaxConstraint() {
        return maxConstraint;
    }

    public void setMaxConstraint(int maxConstraint) {
        this.maxConstraint = maxConstraint;
    }

    public int getMinConstraint() {
        return minConstraint;
    }

    public void setMinConstraint(int minConstraint) {
        this.minConstraint = minConstraint;
    }
}